|PyPI| |PyPIDownloads| |Docs|

.. |PyPI| image:: https://img.shields.io/pypi/v/quanp?logo=PyPI
   :target: https://pypi.org/project/quanp
.. |PyPIDownloads| image:: https://static.pepy.tech/badge/quanp
   :target: https://pepy.tech/project/quanp
.. |Docs| image:: https://readthedocs.org/projects/quanp/badge/?version=latest
    :target: https://quanp.readthedocs.io/en/latest/?badge=latest

Quanp – Quantitative Analysis in Python
=======================================

Quanp is a scalable toolkit for analyzing cross-sectional and longitudinal/time-series 
quantitative data. It was first inspired by `scanpy <https://scanpy.readthedocs.io>`__. and 
jointly built with `anndata <https://anndata.readthedocs.io>`__. It includes
preprocessing, visualization, clustering, features selection/importance. 

Read the documentation_. If you'd like to contribute by opening an issue or creating a pull request,
please take a look at our `contributing guide`_.
If Quanp is useful for your research, consider being a contributor.

.. _documentation: https://quanp.readthedocs.io
.. _contributing guide: CONTRIBUTING.md
